﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using NetworkIt; 

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=391641

namespace WindowsNetwork
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {

        Client client;
        String user = "Aaron";

        int iSongIndex = 0;
        String[] SongList = { "Michael Jackson - Beat It.mp3", "Michael Jackson - Smooth Criminal.mp3", "Michael Jackson - Thriller.mp3" };

        public MainPage()
        {
            this.InitializeComponent();

            this.NavigationCacheMode = NavigationCacheMode.Required;

            this.client = new Client(user, "581.cpsc.ucalgary.ca", 8000);

            this.client.Connected += client_Connected;
            this.client.MessageReceived += client_MessageReceived;

            SongPlayer.Source = new Uri("ms-appx:///Audio/" + SongList[iSongIndex], UriKind.Absolute);
            SongPlayer.Play();

            UpdateVisuals();
        }

        async void client_Connected(object sender, EventArgs e)
        {
            await Dispatcher.RunAsync(Windows.UI.Core.CoreDispatcherPriority.Normal, () =>
            {
                MyTextBox.Text += user + " Connected to server";
            });
        }

        async void client_MessageReceived(object sender, NetworkItMessageEventArgs e)
        {
            await Dispatcher.RunAsync(Windows.UI.Core.CoreDispatcherPriority.Normal, () =>
            {
                if (e.ReceivedMessage.Name == "NextSong")
                {
                    NextSong();
                }
                else if (e.ReceivedMessage.Name == "PreviousSong")
                {
                    PreviousSong();
                }
                else if (e.ReceivedMessage.Name == "VolUp")
                {
                    if( SongPlayer.Volume >= 0.9 )
                        SongPlayer.Volume = 1;
                    else
                        SongPlayer.Volume += 0.1;
                }
                else if (e.ReceivedMessage.Name == "VolDown")
                {
                    if (SongPlayer.Volume <= 0.1)
                        SongPlayer.Volume = 0;
                    else
                        SongPlayer.Volume -= 0.1;
                }
                else if (e.ReceivedMessage.Name == "PauseSong")
                {
                    SongPlayer.Pause();
                }
                else if (e.ReceivedMessage.Name == "PlaySong")
                {
                    SongPlayer.Play();
                }

                UpdateVisuals();
                MyTextBox.Text += "\n Command: " + e.ReceivedMessage.Name;
            } );
        }


        async void UpdateVisuals()
        {
            await Dispatcher.RunAsync(Windows.UI.Core.CoreDispatcherPriority.Normal, () =>
            {
                SongName.Text = SongList[iSongIndex];
                Volume.Text = SongPlayer.Volume.ToString();
            });
        }

        private void NextSong()
        {
            SongPlayer.Pause();

            iSongIndex++;

            if (iSongIndex >= SongList.Length)
                iSongIndex = 0;

            SongPlayer.Source = new Uri("ms-appx:///Audio/" + SongList[iSongIndex], UriKind.Absolute);
            SongPlayer.Play();
        }

        private void PreviousSong()
        {
            SongPlayer.Pause();

            iSongIndex--;

            if (iSongIndex < 0)
                iSongIndex = SongList.Length - 1;

            SongPlayer.Source = new Uri("ms-appx:///Audio/" + SongList[iSongIndex], UriKind.Absolute);
            SongPlayer.Play();
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.
        /// This parameter is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            // TODO: Prepare page for display here.

            // TODO: If your application contains multiple pages, ensure that you are
            // handling the hardware Back button by registering for the
            // Windows.Phone.UI.Input.HardwareButtons.BackPressed event.
            // If you are using the NavigationHelper provided by some templates,
            // this event is handled for you.
        }
    }
}
